Index: runtime/include/dart_api.h |
diff --git a/runtime/include/dart_api.h b/runtime/include/dart_api.h |
index 1201a82fba2708b76e73979132adbc38901860e8..7bd749c38e0def7732033b4d1ec13ea5e4e7ded1 100644 |
--- a/runtime/include/dart_api.h |
+++ b/runtime/include/dart_api.h |
@@ -3218,14 +3218,14 @@ Dart_Precompile(Dart_QualifiedFunctionName entry_points[], |
* - A root library must have been loaded. |
* - Dart_Precompile must have been called. |
* |
- * Outputs a vm isolate snapshot, an isolate snapshot, and an assembly file |
- * defining the symbols kInstructionsSnapshot and kDataSnapshot. The assembly |
+ * Outputs an assembly file defining the symbols kVmIsolateSnapshot, |
+ * kIsolateSnapshot, kInstructionsSnapshot and kDataSnapshot. The assembly |
* should be compiled as a static or shared library and linked or loaded by the |
* embedder. |
* Running this snapshot requires a VM compiled with DART_PRECOMPILED_SNAPSHOT. |
- * The vm isolate snapshot, kInstructionsSnapshot and kDataSnapshot should be |
- * passed as arguments to Dart_Initialize. The isolate snapshot should be |
- * passed to Dart_CreateIsolate. |
+ * The kVmIsolateSnapshot, kInstructionsSnapshot and kDataSnapshot should be |
+ * passed as arguments to Dart_Initialize. The kIsolateSnapshot snapshot should |
+ * be passed to Dart_CreateIsolate. |
* |
* The buffers are scope allocated and are only valid until the next call to |
* Dart_ExitScope. |
@@ -3233,28 +3233,25 @@ Dart_Precompile(Dart_QualifiedFunctionName entry_points[], |
* \return A valid handle if no error occurs during the operation. |
*/ |
DART_EXPORT Dart_Handle |
-Dart_CreatePrecompiledSnapshotAssembly(uint8_t** assembly_buffer, |
- intptr_t* assembly_size); |
+Dart_CreateAppAOTSnapshotAsAssembly(uint8_t** assembly_buffer, |
+ intptr_t* assembly_size); |
/** |
* Same as Dart_CreatePrecompiledSnapshotAssembly, except the instruction and |
* data snapshot pieces are provided directly as bytes that the embedder can |
* load with mmap. The instructions piece must be loaded with read and |
* execute permissions; the rodata piece may be loaded as read-only. |
*/ |
DART_EXPORT Dart_Handle |
-Dart_CreatePrecompiledSnapshotBlob(uint8_t** vm_isolate_snapshot_buffer, |
- intptr_t* vm_isolate_snapshot_size, |
- uint8_t** isolate_snapshot_buffer, |
- intptr_t* isolate_snapshot_size, |
- uint8_t** instructions_blob_buffer, |
- intptr_t* instructions_blob_size, |
- uint8_t** rodata_blob_buffer, |
- intptr_t* rodata_blob_size); |
- |
- |
-DART_EXPORT Dart_Handle Dart_PrecompileJIT(); |
+Dart_CreateAppAOTSnapshotAsBlobs(uint8_t** vm_isolate_snapshot_buffer, |
+ intptr_t* vm_isolate_snapshot_size, |
+ uint8_t** isolate_snapshot_buffer, |
+ intptr_t* isolate_snapshot_size, |
+ uint8_t** instructions_blob_buffer, |
+ intptr_t* instructions_blob_size, |
+ uint8_t** rodata_blob_buffer, |
+ intptr_t* rodata_blob_size); |
/** |
@@ -3281,12 +3278,12 @@ DART_EXPORT Dart_Handle Dart_PrecompileJIT(); |
* \return A valid handle if no error occurs during the operation. |
*/ |
DART_EXPORT Dart_Handle |
-Dart_CreateAppJITSnapshot(uint8_t** isolate_snapshot_buffer, |
- intptr_t* isolate_snapshot_size, |
- uint8_t** instructions_blob_buffer, |
- intptr_t* instructions_blob_size, |
- uint8_t** rodata_blob_buffer, |
- intptr_t* rodata_blob_size); |
+Dart_CreateAppJITSnapshotAsBlobs(uint8_t** isolate_snapshot_buffer, |
+ intptr_t* isolate_snapshot_size, |
+ uint8_t** instructions_blob_buffer, |
+ intptr_t* instructions_blob_size, |
+ uint8_t** rodata_blob_buffer, |
+ intptr_t* rodata_blob_size); |
/** |
@@ -3233,28 +3233,25 @@ Dart_Precompile(Dart_QualifiedFunctionName entry_points[], |
/** |
- * Same as Dart_CreatePrecompiledSnapshotAssembly, except the instruction and |
- * data snapshot pieces are provided directly as bytes that the embedder can |
- * load with mmap. The instructions piece must be loaded with read and |
- * execute permissions; the rodata piece may be loaded as read-only. |
+ * Same as Dart_CreateAppAOTSnapshotAsAssembly, except all the pieces are |
+ * provided directly as bytes that the embedder can load with mmap. The |
+ * instructions piece must be loaded with read and execute permissions; the |
+ * other pieces may be loaded as read-only. |
*/ |
DART_EXPORT Dart_Handle |